# Introduction

Scoutr was built as a means to provide a simple way to put an API in front of a DynamoDB backend and ensure full
RBAC integration.

A Go implementation is available at [scoutr-go](https://github.com/MichaelPalmer1/scoutr-go). The Go version adds support
for Google Firestore and MongoDB (on Azure), in addition to the existing support for AWS DynamoDB. This functionality will be
added to the Python implementation soon.
